#include <arduwire.h>
#include <LiquidCrystal_I2C.h>

arduwire ArduwireUNO(32);
LiquidCrystal_I2C lcd(0x27,20,4);
//CREATE ONE VARIABLE TO STORE THE TEST POINT RETURN FOR THE ARDUWIRE
uint8_t probe_pin = 0;
bool cable_passed = false;
bool cable_ready_to_test = false;
bool cable_failed = false;


void setup() {
  
    ArduwireUNO.init();
    lcd.init();
    draw_margin();
    lcd.backlight();
    lcd.setCursor(3,1);
    lcd.print(F("Selftest:"));
    lcd.setCursor(13,1);
    lcd.print(ArduwireUNO.selftest());
    lcd.setCursor(16,1);
    lcd.print(F("TP"));
    delay(3000);
    clear_lcd();
    lcd.setCursor(5,1);
    lcd.print(F("Learning..."));
    //Waiting, please attach the cable to test!!!
    while(ArduwireUNO.cable_pres()!=true);
    clear_lcd();
    ArduwireUNO.learn();
    delay(100);
    lcd.setCursor(2,1);
    lcd.print(F("Wirelist Learned"));
    lcd.setCursor(9,2);
    lcd.print(ArduwireUNO.get_connections_learned());
    ArduwireUNO.buzzer_on();
    delay(2000);
    clear_lcd();  
}

void loop() {

  if(ArduwireUNO.test()==1){
    if(cable_passed==false){
      lcd.setCursor(2,1);
      lcd.print(F("              "));
	  ArduwireUNO.led_fail_off();
      //ArduwireUNO.set_fail_led(0);
      lcd.setCursor(8,1);
      lcd.print(F("PASS"));
	  ArduwireUNO.led_pass_on();
      //ArduwireUNO.set_pass_led(1);
      cable_passed = true;
      cable_ready_to_test = false;
      cable_failed = false;
    }      
  }
  else{
    //Cable presence
    if(ArduwireUNO.cable_pres()==false){
      if(cable_ready_to_test == false){
        lcd.setCursor(2,1);
        lcd.print(F("            "));
        lcd.setCursor(3,1);
        lcd.print(F("READY TO TEST"));
        cable_passed = false;
		    ArduwireUNO.led_fail_off();
		    ArduwireUNO.led_pass_off();
       // ArduwireUNO.set_pass_led(0);
        //ArduwireUNO.set_fail_led(0);
        cable_ready_to_test = true;
        cable_failed = false;
      }
    }
    else{
      if(cable_failed==false){
        lcd.setCursor(2,1);
        lcd.print(F("                "));
		    ArduwireUNO.led_pass_off();
        //ArduwireUNO.set_pass_led(0);
        lcd.setCursor(8,1);
        lcd.print(F("FAIL"));
		    ArduwireUNO.led_fail_on();
        
        //ArduwireUNO.set_fail_led(1);
        cable_passed = false;
        cable_failed = true;
        cable_ready_to_test = false;
      }
      ArduwireUNO.buzzer_on();
    }
  }
  
}

void draw_margin(){
  lcd.setCursor(0,0);
  lcd.print(F("*---Arduwire UNO---*"));
  
  lcd.setCursor(0,3);
  lcd.print(F("*------------------*"));
  lcd.setCursor(0,1);
  lcd.print(F("|"));
  lcd.setCursor(0,2);
  lcd.print(F("|"));
  
  lcd.setCursor(19,1);
  lcd.print(F("|"));
  lcd.setCursor(19,2);
  lcd.print(F("|"));
}

void clear_lcd(){
  lcd.setCursor(1,1);
  lcd.print(F("                 "));
  lcd.setCursor(1,2);
  lcd.print(F("                 "));
}
